use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Daniel
Etheridge
Florian
Karen
Kogman
MORIYA
Masaki
Mengué
Moore
MooseX
Olivier
Pittman
Ragwitz
Shawn
Types
URI
Yuval
daniel
dolmen
ether
gardejo
irc
lib
moriya
nothingmuch
rafl
sartak
יובל
קוג
